@@ -375,9 +375,7 @@ AttributeError: Can't get cell sizes when coordinates have no bounds
                 "Can't get cell sizes when coordinates have no bounds")
 
         cells = self.bounds.data
-        print cell.array
         cells = (cells[:, 1] - cells[:, 0]).abs()
-        print cell.array
         cells.squeeze(1, i=True)
         
         return cells
@@ -2728,10 +2726,9 @@ False
     #--- End: def
 
     # DimensionCoordinate
-    def get_bounds(self, create=False, insert=False, bound=None, copy=True):
-        '''
-    
-Get the cell bounds.
+    def get_bounds(self, create=False, insert=False, bound=None,
+                   cellsize=None, copy=True):
+        '''Get the cell bounds.
     
 Either return its existing bounds or, if there are none, optionally
 create bounds based on the coordinate array values.
@@ -2783,19 +2780,36 @@ create bounds based on the coordinate array values.
          
         if not create:
             raise ValueError(
-                "Dimension coordinates have no bounds and create=%s" % create)
+                "Dimension coordinates have no bounds and create={0}".format(create))
 
         array = self.unsafe_array
         size = array.size    
 
+        if cellsize is not None:
+            cellsize = Data.asdata(abs(cellsize))
+            if cellsize.Units:
+                if not cellsize.Units.equivalent(self.Units):
+                    raise ValueError("jhgsjhbd jh ")
+                cellsize.Units = self.Units
+            cellsize = cellsize.datum()
+
         if bound is None:
             # Creat Voronoi bounds
             if size < 2:
-                raise ValueError("Can't create bounds for Voronoi cells from one value")
+                if cellsize is not None:
+                    raise ValueError(
+"Can't create bounds for Voronoi cells from one value when cellsize parameter is unset")
 
-            bounds_1d = [array.item(0,)*1.5 - array.item(1,)*0.5]
-            bounds_1d.extend((array[0:-1] + array[1:])*0.5)
-            bounds_1d.append(array.item(-1,)*1.5 - array.item(-2,)*0.5)
+                cellsize  = cellsize * 0.5
+                if not self.direction():
+                    cellsize *= -1
+   
+                coord = array.item(0,)
+                bounds_1d = [coord - cellsize, coord + cellsize]
+            else:
+                bounds_1d = [array.item(0,)*1.5 - array.item(1,)*0.5]
+                bounds_1d.extend((array[0:-1] + array[1:])*0.5)
+                bounds_1d.append(array.item(-1,)*1.5 - array.item(-2,)*0.5)
 
             dtype = type(bounds_1d[0])
 
@@ -2809,20 +2823,17 @@ create bounds based on the coordinate array values.
                 for i in xrange(size):
                     bound = 2.0*array.item(i,) - bound
                     bounds_1d.append(bound)
-
-                dtype = type(bounds_1d[-1])
-
             elif bound >= array.item(-1,):
                 for i in xrange(size-1, -1, -1):
                     bound = 2.0*array.item(i,) - bound
                     bounds_1d.append(bound)
 
-                dtype = type(bounds_1d[-1])
-
                 bounds_1d = bounds_1d[::-1]
             else:
                 raise ValueError("bad bound value")
 
+            dtype = type(bounds_1d[-1])
+
             if not direction:               
                 bounds_1d = bounds_1d[::-1]
         #--- End: if
@@ -2831,6 +2842,28 @@ create bounds based on the coordinate array values.
         bounds[:,0] = bounds_1d[:-1]
         bounds[:,1] = bounds_1d[1:]        
 
+        if cellsize is not None:
+            cells = abs(bounds[:, 1] - bounds[:, 0])
+            cells = cells.squeeze(axis=1)
+            for i, (c, s) in enumerate(zip(array, cells)):
+                if s <= cellsize:
+                    continue
+                if self.direction():
+                    if c - bounds[i,0] <= cellsize:
+                        bounds[i,1] = bounds[i,0] + cellsize
+                    elif bounds[i,1] - c <= cellsize:
+                        bounds[i,0] = bounds[i,1] - cellsize
+                    else:
+                        raise ValueError("asdasdasds8888888888888888888888")
+                else:
+                    if bounds[i,0] - c <= cellsize:
+                        bounds[i,1] = bounds[i,0] - cellsize
+                    elif c - bounds[i,1] <= cellsize:
+                        bounds[i,0] = bounds[i,1] + cellsize
+                    else:
+                        raise ValueError("asdasdasds8888888888888888888888 66767")
+        #--- End: if
+
         bounds = CoordinateBounds(data=Data(bounds, self.Units), copy=False)
                            
         if insert:
