@@ -41,6 +41,7 @@ from itertools   import product as itertools_product
 from itertools   import izip, izip_longest
 from platform    import system
 from psutil      import virtual_memory, Process
+from math        import ceil as math_ceil
 
 from .constants import CONSTANTS, _file_to_fh
 
@@ -2064,7 +2065,8 @@ between ``a`` and ``b``.
     return _numpy_allclose(x, y, rtol=rtol, atol=atol)
 #--- End: def
 
-def _section(o, axes=None, data=False, stop=None, **kwargs):
+def _section(o, axes=None, data=False, stop=None, chunks=False,
+             min_step=1, **kwargs):
     """
 
 Return a list of m dimensional sections of a Field of n dimensions or
@@ -2091,12 +2093,23 @@ cf.Data.
     
     data : bool, optional
         If True this indicates that a data object has been passed, if
-        false it indicates that a field object has been passed. By
-        default it is false.
+        False it indicates that a field object has been passed. By
+        default it is False.
 
     stop : int, optional
         Stop after taking this number of sections and return. If stop
         is None all sections are taken.
+    
+    chunks : bool, optional
+        If True return sections that are of the maximum possible size
+        that will fit in one chunk of memory instead of sectioning
+        into slices of size 1 along the dimensions that are being
+        sectioned.
+    
+    min_step : int, optional
+        The minimum step size when making chunks. By default this is
+        1. Can be set higher to avoid size 1 dimensions, which are
+        problematic for bilinear regridding.
 
 :Returns:
 
@@ -2138,13 +2151,33 @@ names:
     #--- End: if
     
     # find the size of each dimension
-    if data:
-        sizes = o.shape
-    else:
-        sizes = []
-        for axis in o.data_axes():
-            sizes.append(o.axis_size((axis)))
+    sizes = o.shape
+    
+    if chunks:
+        steps = list(sizes)
+        
+        # Define the factor which, when multiplied by the size of the
+        # data array, determines how many chunks are in the data array.
+        factor = (o.dtype.itemsize + 1.0)/CHUNKSIZE()
+        
+        # n_chunks = number of equal sized bits the partition
+        #            needs to be split up into so that each bit's
+        #            size is less than ther chunk size.
+        n_chunks = int(math_ceil(o.size*factor))
+        
+        for (index, axis_size) in enumerate(sizes):
+            if int(math_ceil(float(axis_size)/min_step)) <= n_chunks:
+                n_chunks = int(math_ceil(n_chunks/float(axis_size)*min_step))
+                steps[index] = min_step
+                
+            else:
+                steps[index] = int(axis_size/n_chunks)
+                
+                break
+            #--- End: if
         #--- End: for
+    else:
+        steps = [1] * len(sizes)
     #--- End: if
     
     # use recursion to slice out each 2D horizontal section
@@ -2169,8 +2202,7 @@ names:
         
         if current_index < 0:
             if data:
-                d[tuple([None if x == slice(None) else x for x in indices])] \
-                    = o[tuple(indices)]
+                d[tuple([x.start for x in indices])] = o[tuple(indices)]
             else:
                 fl.append(o.subspace[tuple(indices)])
             #--- End: if
@@ -2183,10 +2215,10 @@ names:
             return
         #--- End: if
         
-        for i in range(sizes[current_index]):
+        for i in range(0, sizes[current_index], steps[current_index]):
             if not stop is None and nl_vars['count'] >= stop:
                 return
-            indices[current_index] = i
+            indices[current_index] = slice(i, i + steps[current_index])
             loop_over_index(current_index - 1)
         #--- End: for
     #--- End: def
